Devicetree
 help / color / mirror / Atom feed
From: ASHISH YADAV <ashishyadav78@gmail.com>
To: Guenter Roeck <linux@roeck-us.net>, Rob Herring <robh@kernel.org>,
	Krzysztof Kozlowski <krzk+dt@kernel.org>,
	Conor Dooley <conor+dt@kernel.org>
Cc: linux-hwmon@vger.kernel.org, devicetree@vger.kernel.org,
	linux-kernel@vger.kernel.org,
	Ashish Yadav <ashish.yadav@infineon.com>
Subject: [PATCH 2/2] hwmon:(pmbus/xdpe1a2g7b) Add support for xdpe1a2g7c controller
Date: Mon, 21 Sep 2026 12:27:02 +0530	[thread overview]
Message-ID: <20260921065702.93196-3-Ashish.Yadav@infineon.com> (raw)
In-Reply-To: <20260921065702.93196-1-Ashish.Yadav@infineon.com>

From: Ashish Yadav <ashish.yadav@infineon.com>

Extend xdpe1a2g7b driver to support xdpe1a2g7c model.

Signed-off-by: Ashish Yadav <ashish.yadav@infineon.com>
---
 drivers/hwmon/pmbus/Kconfig      |  4 ++--
 drivers/hwmon/pmbus/xdpe1a2g7b.c | 10 ++++++----
 2 files changed, 8 insertions(+), 6 deletions(-)

diff --git a/drivers/hwmon/pmbus/Kconfig b/drivers/hwmon/pmbus/Kconfig
index eb71a0ac044b..f65a295d09a4 100644
--- a/drivers/hwmon/pmbus/Kconfig
+++ b/drivers/hwmon/pmbus/Kconfig
@@ -867,7 +867,7 @@ config SENSORS_XDPE1A2G7B
 	tristate "Infineon XDPE1A2G7B"
 	help
 	  If you say yes here you get hardware monitoring support for Infineon
-	  XDPE1A2G5B and XDPE1A2G7B.
+	  XDPE1A2G5B,XDPE1A2G7B and XDPE1A2G7C.
 
 	  This driver can also be built as a module. If so, the module will
 	  be called xdpe1a2g7b.
@@ -877,7 +877,7 @@ config SENSORS_XDPE1A2G7B_REGULATOR
 	depends on SENSORS_XDPE1A2G7B && REGULATOR
 	help
 	  If you say yes here you get regulator support for Infineon
-	  XDPE1A2G5B and XDPE1A2G7B multi-phase digital controllers.
+	  XDPE1A2G5B,XDPE1A2G7B and XDPE1A2G7C multi-phase digital controllers.
 
 	  This enables the controllers to be used as regulator devices,
 	  providing voltage control through the regulator framework.
diff --git a/drivers/hwmon/pmbus/xdpe1a2g7b.c b/drivers/hwmon/pmbus/xdpe1a2g7b.c
index 9455ef443b2b..48f6f8081c4b 100644
--- a/drivers/hwmon/pmbus/xdpe1a2g7b.c
+++ b/drivers/hwmon/pmbus/xdpe1a2g7b.c
@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
  * Hardware monitoring driver for Infineon Multi-phase Digital XDPE1A2G5B
  * and XDPE1A2G7B Controllers
  *
  * Copyright (c) 2026 Infineon Technologies. All rights reserved.
  */
@@ -23,7 +23,7 @@ static int xdpe1a2g7b_identify(struct i2c_client *client,
 	int vout_mode;
 
 	/*
-	 * XDPE1A2G5B and XDPE1A2G7B support both Linear and NVIDIA PWM VID data
+	 * XDPE1A2G5B and XDPE1A2G7B/7C support both Linear and NVIDIA PWM VID data
 	 * formats via VOUT_MODE. Note that the device pages/loops are not fully
 	 * independent: configuration is shared, so programming each page/loop
 	 * separately is not supported.
@@ -100,6 +100,7 @@ static int xdpe1a2g7b_probe(struct i2c_client *client)
 static const struct i2c_device_id xdpe1a2g7b_id[] = {
 	{ .name = "xdpe1a2g5b" },
 	{ .name = "xdpe1a2g7b" },
+	{ .name = "xdpe1a2g7c" },
 	{ }
 };
 
@@ -108,6 +109,7 @@ MODULE_DEVICE_TABLE(i2c, xdpe1a2g7b_id);
 static const struct of_device_id __maybe_unused xdpe1a2g7b_of_match[] = {
 	{ .compatible = "infineon,xdpe1a2g5b" },
 	{ .compatible = "infineon,xdpe1a2g7b" },
+	{ .compatible = "infineon,xdpe1a2g7c" },
 	{}
 };
 
@@ -125,6 +127,6 @@ static struct i2c_driver xdpe1a2g7b_driver = {
 module_i2c_driver(xdpe1a2g7b_driver);
 
 MODULE_AUTHOR("Ashish Yadav <ashish.yadav@infineon.com>");
-MODULE_DESCRIPTION("PMBus driver for Infineon XDPE1A2G5B/7B");
+MODULE_DESCRIPTION("PMBus driver for Infineon XDPE1A2G5B/7B/7C");
 MODULE_LICENSE("GPL");
 MODULE_IMPORT_NS("PMBUS");
@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
- * Hardware monitoring driver for Infineon Multi-phase Digital XDPE1A2G5B
- * and XDPE1A2G7B Controllers
+ * Hardware monitoring driver for Infineon Multi-phase Digital XDPE1A2G5B,
+ * XDPE1A2G7B and XDPE1A2G7C Controllers
  *
  * Copyright (c) 2026 Infineon Technologies. All rights reserved.
-- 
2.39.5


  parent reply	other threads:[~2026-09-21  6:57 UTC|newest]

Thread overview: 11+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-09-21  6:57 [PATCH 0/2] Add support for Infineon Digital Multi-phase ASHISH YADAV
2026-09-21  6:57 ` [PATCH 1/2] dt-bindings: trivial-devices: Add support for XDPE1A2G7C ASHISH YADAV
2026-09-21  7:01   ` sashiko-bot
2026-09-25 12:58   ` Krzysztof Kozlowski
2026-09-26  3:29   ` Guenter Roeck
2026-09-21  6:57 ` ASHISH YADAV [this message]
2026-09-21  7:01   ` [PATCH 2/2] hwmon:(pmbus/xdpe1a2g7b) Add support for xdpe1a2g7c controller sashiko-bot
2026-09-26  3:29   ` Guenter Roeck
2026-09-25  6:31 ` [PATCH 0/2] Add support for Infineon Digital Multi-phase ashish yadav
2026-09-25 13:00   ` Krzysztof Kozlowski
2026-09-25 14:00   ` Guenter Roeck

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260921065702.93196-3-Ashish.Yadav@infineon.com \
    --to=ashishyadav78@gmail.com \
    --cc=ashish.yadav@infineon.com \
    --cc=conor+dt@kernel.org \
    --cc=devicetree@vger.kernel.org \
    --cc=krzk+dt@kernel.org \
    --cc=linux-hwmon@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux@roeck-us.net \
    --cc=robh@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox